<script setup>
import {$go} from '../../composables/goto';
import {Tools} from "@element-plus/icons-vue";
</script>


<template>
    <AppLayout title="Clients">
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight"> Client Accounts
                <el-button text type="primary" size="small" class="ml-4" rounded @click="$go(route('clients.create'))">
                    <el-icon class="el-icon--left">
                        <Plus/>
                    </el-icon>
                    Add Client
                </el-button>
            </h2>
        </template>
        <div>
            <div class="max-w-6xl mx-auto py-5 sm:px-2 mt-8 ">
                <el-empty description="No client has been added yet." v-if="!clients.length">
                    <el-button @click="$go(route('clients.create'), {data: {}})" link class="uppercase" size="small"
                               type="primary">
                        <el-icon class="el-icon--left">
                            <Plus/>
                        </el-icon>
                        Add client
                    </el-button>
                </el-empty>
                <div v-else>
                    <el-table size="small" :data="clients" style="width: 100%">
                        <el-table-column label="#" width="25">
                            <template #default="scope">
                                {{ scope.$index + 1 }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="name" label="Organisation" width="100px" show-overflow-tooltip/>
                        <el-table-column prop="username" label="Login" width="100px" show-overflow-tooltip/>
                        <el-table-column label="Status" width="80px" align="center">
                            <template #default="scope">
                                <el-tag effect="dark" :type="`${scope.row.active ? 'success':'warning'}`">
                                    {{ scope.row.active ? 'Active' : 'Inactive' }}
                                </el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column label="LICENSE" align="center" width="70px">
                            <template #default="scope">
                                <small v-if="scope.row.active_license.active"
                                       :class="[scope.row.active_license.code === 1? 'text-green-400':'text-orange-400']">
                                    {{ scope.row.active_license.status }}</small>
                                <small v-else>NONE</small>
                            </template>
                        </el-table-column>
                        <el-table-column prop="email" label="Email" show-overflow-tooltip/>
                        <el-table-column prop="address" label="Address" width="90px" show-overflow-tooltip/>
                        <el-table-column prop="contact" label="Contact" width="100px" show-overflow-tooltip/>
                        <el-table-column label="Reference" align="center" show-overflow-tooltip>
                            <template #default="scope">
                                <el-popover effect="dark" trigger="hover" placement="top" width="auto">
                                    <template #default>
                                        <div>Name: {{ scope.row.ref_name }}</div>
                                        <div>E-mail: {{ scope.row.ref_email }}</div>
                                        <div>Contact: {{ scope.row.ref_contact }}</div>
                                        <div>Address: {{ scope.row.ref_address }}</div>
                                    </template>
                                    <template #reference>
                                        <el-tag size="small">{{ scope.row.ref_name }}</el-tag>
                                    </template>
                                </el-popover>
                            </template>
                        </el-table-column>
                        <el-table-column label="Actions" min-width="120px">
                            <template #header>
                                <el-icon size="small" class="el-icon--left">
                                    <Tools/>
                                </el-icon>
                                Actions
                            </template>
                            <template #default="scope">
                                <ConfirmsPassword @confirmed="updateStatus(scope.row.id, scope.$index)">
                                    <el-button :type="scope.row.active? 'danger' : 'success'" size="small">
                                        <el-icon class="el-icon--left">
                                            <CircleClose v-if="scope.row.active"/>
                                            <CircleCheck v-else/>
                                        </el-icon>
                                        {{ scope.row.active ? 'Deacti....' : 'Activate' }}
                                    </el-button>
                                </ConfirmsPassword>
                                <el-button @click="$go(route('licenses', {client: scope.row.id}))" type="info"
                                           size="small" class="ml-2"><el-icon class="el-icon--left"><Tickets/></el-icon>Licenses
                                </el-button>
                                <el-dropdown class="float-right mt-1">
                                    <span class="el-dropdown-link">
                                      <el-icon class="el-icon--right rotate-90"><More/></el-icon>
                                    </span>
                                    <template #dropdown>
                                        <el-dropdown-menu>
                                            <el-dropdown-item :icon="Tools">Edit Info</el-dropdown-item>
                                            <el-dropdown-item :icon="Lock">
                                                Reset Password</el-dropdown-item>
                                        </el-dropdown-menu>
                                    </template>
                                </el-dropdown>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
            </div>
        </div>
    </AppLayout>
</template>

<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import {Plus, Delete, Tools, Tickets, CircleCheck, CircleClose, Lock, More} from '@element-plus/icons-vue';
import {reactive, ref} from "vue";
import ConfirmsPassword from '@/Components/ConfirmsPassword.vue'

export default {
    name: "Client",
    components: {
        Plus, Delete, Tickets, CircleCheck, CircleClose, More,
        AppLayout, ConfirmsPassword
    },
    data() {
        return {
            clients: ref(this.$page.props.clients),
        }
    },
    methods: {
        updateStatus(client, index) {
            axios.post(route('clients.status', [client]))
                .then(res => res.data)
                .then(data => {
                    this.clients.splice(index, 1, data)
                })
        }
    }
}
</script>

<style scoped>

</style>
